function get_jmovie_times, jmovie, giffiles, _extra=_extra, out_style=out_style
;+
;   Name: get_jmovie_times
;
;   Purpose: return frame times from JS movie GIF files (assume FID included)
;
;   Input Parameters:
;      jmovie - JS movie name (generally .xxxx.html or xxxx_j.html)
;  
;   Keyword Parameters:
;      out_style - any 'anytim' / 'file2time' output style   
;      _extra - alternate out_style specification by /XXX (keyword inherit)
;
;   History:
;      12-May-1998 - S.L.Freeland - 
;-
if not data_chk(jmovie,/string) or n_elements(jmovie) gt 1 then begin
  box_message,'IDL>times=get_jmovie_times(jsmoviename)'
  return,-1
endif

jsmovie=jmovie(0)             ; force scalar

if not file_exist(jsmovie) then begin
   box_message,'No file found:'+jsmovie
   return,-1
endif

contents=strtrim(rd_tfile(jsmovie),2)
marker='*gif";'

ss=wc_where(contents,'*'+marker,count)
if count eq 0 then begin
  box_message,'Cant find gif files
  return, -1
endif

if data_chk(_extra,/struct) and not keyword_set(out_style) then $
   out_style=(tag_names(_extra))(0)

times=file2time(contents(ss),out_style=out_style)
giffiles=strextract(contents(ss),'"','"')

return,times
end
