pro last_trace, index, data, count, mosaic=mosaic, map=map, $
		percent=percent, _extra=_extra, wave=wave, prepit=prepit,  $
		source_area=source_area, noscale=noscale, lastxx=lastxx, $
		start_time=start_time, stop_time=stop_time
;
;   Name: last_trace
;
;   Purpose: return the latest 'interesting' TRACE images or mosaics sets
;
;   Input Parameters:
;      count - optional number of images to return
;
;   Output Parameters:
;      index - the index structures  
;      data  - the 2D or 3D data array
;
;   Keyword Parameters:
;      percent     - quality cutoff (default=100%)
;      wave        - wavelenght
;      prepit      - if set, run data through TRACE_PREP
;      source_area - source area filter (default=0)
;      /WXXX       - optionally define wavelenths like: /w171, /w195, /w1216
;      mosaic      - if set, get latest mosaic set in specified wavelenth
;      map         - if set, output is in DMZ map-space
;
;   History:
;      23-April-1998 - S.L.Freeland - illustrate some TRACE/SSW techniques
;                      and provide a useful service at the same time.  
;   Calls:
;       trace_cat, trace_cat2data, read_trace, trace_prep, data_chk, $
;       deriv_arr
;
;   Method: use TRACE catalog, simple filters and catalog->data mapping SW  
;-  
 mosaic=keyword_set(mosaic)
; ----------------- wavelength selection --------------
case 1 of
  keyword_set(wave): iwave=wave
  data_chk(_extra,/struct): begin
    tags=(tag_names(_extra))(0)
    if strmid(tags,0,1) eq 'W' then iwave=fix(strmid(tags,1,5)) else iwave=171
  endcase
  else: iwave=171
endcase
swave=strtrim(iwave,2)
;-----------------------------------------------------------
if not keyword_set(source_area) then source_area=0
if not keyword_set(percent) then percent=100       ; default=perfect
obsstr=(['','fulldisk'])(mosaic)

if keyword_set(start_time) then begin
  if not keyword_set(stop_time) then stop_time=timegrid(start_time,hour=48,/string)
  trace_cat,start_time,stop_time,catalog
endif else begin trace_cat, /last128,catalog       ; default is newest
; --------------- the filter -----------------------------
ss=where(strpos(catalog.obs_prog,obsstr) ne -1   and    $
	        catalog.wave_len eq swave        and    $
                catalog.percentd ge percent      and    $
                (catalog.naxis1 eq 1024 and catalog.naxis2 eq 1024) and $
                catalog.sou_area eq source_area,         icnt)
;-----------------------------------------------------------
if icnt lt 0 then begin
    box_message,'No images match your criteria'
    return
endif    

;-----------------------------------------------------------
ss=reverse(ss)                           ; consider most recent first
secs=int2secarr(catalog(ss))             ; useful index
dsec=deriv_arr(secs)                     ; dT discrimination
cutoff=where(abs(dsec) gt 2000)          ; uniq mosaic set determination
;-----------------------------------------------------------
case 1 of
    n_elements(count) gt 0: nimg=count    ; user specified
    mosaic: begin
       nimg=cutoff(0)>0<26              ; mosaic 
     endcase       
    else: nimg=0                          ; default is latest single image
endcase
ss=reverse(ss(0:nimg(0) < (n_elements(ss)-1)))                 ; make time go forward again

;-----------------------------------------------------------
trace_cat2data,catalog(ss),files,dset,/filedset  ; catalog->data mapping
read_trace, files, dset, index, data,/all,nodata=n_params() lt 2  ; read the data
box_message,['Read image'+(['','s'])(n_elements(index) gt 0)+':', $
   get_infox(index,/fmt_tim,'wave_len,naxis1,naxis2,obs_prog',format='a4,i5,i5,a')]	     
;-----------------------------------------------------------

if n_elements(data) gt 0 then begin 
   if keyword_set(prepit) then begin
      trace_prep, index, data, outindex, outdata
   endif else data=data-85.
   if not keyword_set(noscale) then $
       data=bytscl(alog10(data>1) )
endif else box_message,'Only read headers since no DATA output paramter supplied'
return
end
