pro map2index, map, index, data, err=err
;+
;   Name: map2index
;
;   Purpose: convert DMZ map object to "standard" index
;
;   Input Parameters:
;      an image map or map array
;      index - IDL structure(s) with "standard" tags derived from map 
;      data  - 2D or 3D map data
; 
;   History:
;      9-April-1998 - S.L.Freeland using Dominic Zarro map2fits 
;-
help,map,/str
err=''
on_error,1

if (not valid_map(map)) then begin
  pr_syntax,'map2index, map, index, data
  return
endif

np=n_elements(map)

; expect original index saved as property-if not, use SSW standard template 
index=gt_tagval(map,/index,missing=sswfits_struct() )

;------ use first as template ------------ 
sdata0=gt_tagval(map(0),/data)
data=make_array(data_chk(sdata0,/nx),data_chk(sdata0,/ny),np,/nozero,$
                type=data_chk(sdata0,/type))

; do some structure filling outside of loop (vector operations)
index.ctype1= 'solar_x'
index.ctype2= 'solar_y'
units1= gt_tagval(map,/units,missing='arcsecs')
units2= gt_tagval(map,/units,missing='arcsecs')
if tag_exist(index,'cunit1') then index.cunit1 =units1 ; else add_tag?
if tag_exist(index,'cunit2') then index.cunit2 =units2 ; else add_tag?
index.crpix1= 1
index.crpix2= 1
index.cdelt1=gt_tagval(map,/dx)
index.cdelt2=gt_tagval(map,/dy)
index.date_obs=anytim(gt_tagval(map,/date_obs),/ccsds)

if tag_exist(map,'dur') and tag_exist(index,'exptime') then $
   index.exptime=gt_tagval(map,/exptime)
if tag_exist(index,'origin') then index.origin=map.id
if tag_exist(map,'soho') then index.telescop='SOHO'

for i=0,np-1 do begin 
;    ----------- unpack data --------
     unpack_map,map(i),mdata,xp,yp,dx=dx,dy=dy,xc=xc,yc=yc,err=err
     data(0,0,i)=temporary(mdata)
     index(i).crval1=xp(0,0)+dx/2.
     index(i).crval2=yp(0,0)+dy/2.
endfor
return & end
