function ssw_deltat, t0, t1, $
   seconds=seconds, minutes=minutes, hours=hours, days=days, loud=loud
;
;+
;   Name: ssw_deltat
;
;   Purpose: return maximum DeltaT between input times in specified units
;      
;   Input Parameters:
;       t0 - start time OR a vector of times
;       t1 - if t0 is scaler start time, t1 = corresponding stop time
;
;   Calling Sequence:
;      dt=ssw_deltat(t0,t1)			; explicit start and stop time
;      dt=ssw_deltat(times)			; vector of times   
;
;   Calling Examples:
;      dt=ssw_delta(index)
;
;   History:
;      Circa 1-jan-1997 - S.L.Freeland
;      25-May-1998 - use <anytim> in place of <anytim2ints>  
;-

case n_params() of 
   0: message,"Need input timess..."
   1: times=t0
   2: times=[t0(0),t1(0)]
   else:
endcase

case 1 of
   keyword_set(seconds): factor=1.
   keyword_set(minutes): factor=1./60.
   keyword_set(hours): factor=1./(60.*60.)
   keyword_set(days): factor=1./(60.*60.*24)
   else: factor=1.0
endcase

deltat=deriv_arr(anytim(times,/tai))*factor

return,deltat

end
