pro trace_cat, t0, t1, catalog, short=short, _extra=_extra
;+
;   Name: trace_cat
;
;   Purpose: read TRACE catalog (via setup/call to 'read_genxcat')  
;
;   Input Parameters:
;      t0, t1 - timerange for read
;
;   Keyword Parameters:
;      short - if set, read/return catalog 'short form'
;  
;   Output:
;      catalog - catalog entries (idl strutures) between t0 and t1  
;
;   Callling Sequence:
;        trace_cat, t0 , t1, catalog [,/short]
;   -OR- trace_cat, catalog , /LASTXX (last XX hours)
;   History:
;      16-April-1998 - S.L.Freeland - provide TRACE front end to read_genxcat
;      18-April-1998 - S.L.Freeland - add /LASTXX option
;
;-  
tdb=get_logenv('tdb')

if n_params() eq 0 then begin
   box_message,['     IDL> trace_cat, t0, t1, catalog [,/short]' , $ 
                '-OR- IDL> trace_cat, catalog , /LASTXX        ;last XX hours']
   return
endif

if tdb(0) eq '' then tdb=concat_dir('SSWDB','tdb')
if not file_exist(tdb) then tdb='/DataCenter/trace/tdb'
if not file_exist(tdb) then begin
   box_message,'Cannot find $tdb or $SSWDB/tdb'
   return
endif

case 1 of
  keyword_set(short): catdir=concat_dir(tdb,'tcs')
  else: catdir=concat_dir(tdb,'tcl')
endcase

; allow /lastxxx where xxx=hours
option=0
if data_chk(_extra,/struct) then begin
   tags=tag_names(_extra)
   hours=(where( strpos(tags,'LAST') ne -1 ,hcnt))(0)
   if hcnt gt 0 then begin
      hours=strmid(tags(hours),4,3)   
      if not is_number(hours) then hours=24
      t1=ut_time()
      t0=timegrid(t1,hour=-(hours),/string)
      box_message,'/LAST set, Using times: ' + t0 + ' - ' + t1
      option=1
    endif
endif

read_genxcat,t0, t1, catalog, topdir=catdir, /init

if option and n_elements(catalog) gt 0 then t0=temporary(catalog)
 
return
end
