pro trace_colors,wave, r, g, b, $
	  load=load, full_range=full_range, max_colors=max_colors, $
	  save_colors=save_colors
;+
;   Name: trace_colors  
;
;   Purpose: return TRACE wave dependent RGB; optionally loadit
;
;   Input Parameters:
;      wave - wavelength - optionally a TRACE index record
;
;   Output Parameters:
;      R,G,B - the associated color table
;
;   Calling Sequence:
;      trace_colors, wave [,r,g,b] [,/load]  
;
;   Keyword Parameters:
;      load - switch, if set loadit (default if no RGB output requested)  
;
;   History:
;        22-May-1998 - CJS 
;        25-May-1998 - S.L.Freeland - => ssw, made it trace_colors, allow index
;         9-Jun-1998 - S.L.Freeland - => fix saturation in last element
;   Notes:  These color scales work best in conjuction with scaling
;           as in routine trace_scale
; 
;
loadit=keyword_set(load) or n_params() eq 1             ; loading requested
;
if n_elements(save_colors) eq 0 then save_colors=2 
tcmax=([254,!p.color-save_colors])(keyword_set(full_range))

if n_params() lt 1 then begin
   message,/info,"IDL> trace_colors, wave [r,g,b] [,/load]  
   return
endif   

n=!d.table_size
sc=200

if keyword_set(max_colors) then sc=max_colors
; derive wave (explicit or via index structure)
iwave=0                                              ; default-> greyscale 
case 1 of
   data_chk(wave,/struct):begin                      ; structure input?
       swave=gt_tagval(wave(0),/wave_len,missing=0)       
       if is_number(swave) then iwave=fix(swave)          ; wave_len->integer
   endcase
   is_number(wave): iwave=wave                      ; explicit input
   else: message,/info,"Unexpected WAVE input, returning greyscale"
endcase   
      
nlowb=fix(3.*n/5.)
nlowg=([fix(1.*n/7),fix(1.*n/5.)])(iwave ge 1600)
nlowr=([fix(n/5),fix(n/2.)])(iwave ge 1600)

case iwave of
   171: begin
      b=byte([findgen(nlowb)/nlowb*sc,$
        sc+findgen(n-nlowb)*(tcmax-sc)/(n-nlowb)])
      g=byte([intarr(nlowg),findgen(nlowb-nlowg)*sc/(nlowb-nlowg),$
        sc+findgen(n-nlowb)*55./(n-nlowb)]*.9)
      r=byte([intarr(nlowr),findgen(nlowb-nlowr)*sc/(nlowb-nlowr),$
        sc+findgen(n-nlowb)*55./(n-nlowb)]*.9)
    endcase

    195: begin
      g=byte([findgen(nlowb)/nlowb*sc,$
        sc+findgen(n-nlowb)*(tcmax-sc)/(n-nlowb)])
      b=byte([intarr(nlowg),findgen(nlowb-nlowg)*sc/(nlowb-nlowg),$
        sc+findgen(n-nlowb)*55./(n-nlowb)]*.9)
      r=byte([intarr(nlowr),findgen(nlowb-nlowr)*sc/(nlowb-nlowr),$
        sc+findgen(n-nlowb)*55./(n-nlowb)]*.9)
    endcase

    284:  begin
       r=byte([findgen(nlowb)/nlowb*sc,$
         sc+findgen(n-nlowb)*(tcmax-sc)/(n-nlowb)])
       g=r
       b=byte([intarr(nlowr),findgen(nlowb-nlowr)*sc/(nlowb-nlowr),$
        sc+findgen(n-nlowb)*55./(n-nlowb)]*.9)
     endcase

    1216:  begin
       sc=220.
       g=byte([findgen(nlowb)/nlowb*sc,sc+findgen(n-nlowb)*(tcmax-sc)/(n-nlowb)])
       b=g
       r=byte(findgen(n)/float(n)*255)
    endcase

    1550:  begin
       sc=190. & off=30.
       nlowr=fix(n/4.)
       r=byte([findgen(nlowb)/nlowb*(sc-off)+off,$
           sc+findgen(n-nlowb)*(tcmax-sc)/(n-nlowb)])
       g=byte([intarr(nlowg),findgen(nlowb-nlowg)*sc/(nlowb-nlowg),$
           sc+findgen(n-nlowb)*55./(n-nlowb)]*.95)
       b=byte([intarr(nlowr),findgen(nlowb-nlowr)*sc/(nlowb-nlowr),$
         sc+findgen(n-nlowb)*55./(n-nlowb)]*.95)
    endcase


    1600: begin
       sc=190. & off=30.
       r=byte([findgen(nlowb)/nlowb*(sc-off)+off,$
          sc+findgen(n-nlowb)*(tcmax-sc)/(n-nlowb)])
       g=byte([intarr(nlowg),findgen(nlowb-nlowg)*sc/(nlowb-nlowg),$
         sc+findgen(n-nlowb)*55./(n-nlowb)]*.95)
       b=byte([intarr(nlowr),findgen(nlowb-nlowr)*sc/(nlowb-nlowr),$
          sc+findgen(n-nlowb)*55./(n-nlowb)]*.75)
     endcase

     1700:  begin
        sc=170.
        r=byte([findgen(nlowb)/nlowb*sc,$
           sc+findgen(n-nlowb)*(tcmax-sc)/(n-nlowb)])
        g=byte([intarr(nlowg),findgen(nlowb-nlowg)*sc/(nlowb-nlowg),$
           sc+findgen(n-nlowb)*55./(n-nlowb)])
        b=byte([intarr(nlowr),findgen(nlowb-nlowr)*sc/(nlowb-nlowr),$
           sc+findgen(n-nlowb)*55./(n-nlowb)]*.55)
      endcase
      else: ssw_ct2rgb,0,r,g,b
endcase

if loadit then tvlct,r,g,b           ; load on request 

return
end
