function trace_files, t0 ,t1, weeks=weeks, week_dirs=week_dirs
;+
;   Name: trace_files
;
;   Purpose: return trace reformatted file names between t0 and t1
;
;   Input Parameters:
;      t0 , t1 - start and stop times 
;
;   Calling Sequence:
;      filelist=trace_files(t0, t1 [,weeks=weeks] )
;
;   Keyword Parameters:
;      weeks - asscociated weekly directories
;  
;   History:
;      26-March-1998 - S.L.Freeland - (based on eit_files, cds_files, etc)
;      16-April-1998 - S.L.Freeland - optimized time selection
;
;   Restrictions:
;      parent directory $TRACE_I1_DIR must be defined ('tri' parent)
;-  

topenv='TRACE_I1_DIR'
toptrace=get_logenv(topenv)

if not file_exist(toptrace) then begin 
   box_message,'Need to define '+topenv +' (parent of weekly subdirectories)'
   return,''
endif

;; if times passed, form weekly subdirectorie
case 1 of 
   n_params() eq 0:  weeks=file_list(toptrace,'week*')
   else: begin
      if n_elements(t1) eq 0 then t1=timegrid(t0,hour=23.99,/string)
      grid=timegrid(t0,t1,/day,/quiet)
      weeks='week'+anytim2weekinfo(grid,/first)
      weeks=concat_dir(toptrace,weeks(uniq(weeks)))
    endelse
endcase

retval=file_list(weeks,'tri*',/cd)

if n_params() gt 0 then begin 
   fids=extract_fid(retval)
   fid0=time2file(t0,delim='.')
   fid1=time2file(t1,delim='.')
   ss=where(fids ge fid0 and fids le fid1,sscnt)   
   if sscnt eq 0 then retval='' else retval=retval(ss)
endif

return,retval
end
