function trace_index2macrofov, index, stringx=stringx, $
		      macroamin=macroamin, macroasec=macroasec
;+
;   Name: trace_index2macrofov
;
;   Purpose: return 'macropixel' location  from xcen/ycen
;
;   History:
;      6-May-1998 - S.L.Freeland - help automate related image/movie set ID
;
;   Input Parameters:
;        index - index or catalog records (assume contain XCEN/YCEN in ")
;
;   Output:
;      Function returns string of form [N/S]XX_[E/W]XX
;        where: XX in arcmin  
;  
;   Keyword Parameters:
;      macroamin - size of 'macro pixel' in arcminutes  (default=2')
;      macroasec - size of 'marco pixel' in arcseconds  (default=120")
;      stringx   - output is string of form NSXX_EWXX , XX in arcmin
;                  (positive NORTH and WEST)
;
;-
if not data_chk(index,/struct) then begin
   box_message,['IDL> retval=trace_index2macrofov(index)']
   return,''
endif  

if not required_tags(index,'xcen,ycen',miss=miss) then begin
   box_message,['Required tags are missing', miss]     
   retval,''    
endif

case 1 of 
   keyword_set(macroamin): asfact=macroamin*60.
   keyword_set(macroasec): asfact=float(macroasec)
   else: asfact=120.
endcase

ns=(['N','S'])(index.ycen lt 0)
ew=(['W','E'])(index.xcen lt 0)

nsmag=abs(round( (index.ycen/asfact)*(asfact/60.)) )
ewmag=abs(round( (index.xcen/asfact)*(asfact/60.)) )

retval=ns+fstring(nsmag,format='(i2.2)') + '_' + $
       ew+fstring(ewmag,format='(i2.2)')
	
return,retval
end
