function trace_uniq_movies, input, matchss,  $
     obs_prog=obs_prog, source_area=source_area, fov=fov, wave_len=wave_len, $
     notest=notest, ustring=ustring, exclude=exclude, minframes=minframes
;+
;   Name: trace_uniq_movies
;
;   Purpose: identify uniq movies from input structures (index or catalog)
;
;   Calling Sequence:
;      (generally called from cron/movie/image maker routines)
;      umovies=trace_uniq_movies(input)       ; return uniq movie records
;      ss=trace_uniq_movies(input, umovrec)   ; subscripts of 'current' movie  
;
;   History:
;     24-Apr-1998 - S.L.Freeland - assist in auto-movie-making
;      6-May-1998 - S.L.Freeland - include call to 'trace_index2macrofov'
;     12-Jun-1998 - S.L.Freeland - add Exposure time (SHT_MDUR)
;  
;   Method:
;      look at observing program, wavelenths, source area and FOV
;      to determine 'uniq' data sets in input   
;-
common trace_uniq_movies_blk, umtemplate
if n_elements(umtemplate) eq 0 then umtemplate =$	
  {nmatches:0l, uname:'', obs_prog:'', wave_len:'', sou_area:0, sht_mdur:0, macrofov:''}

reqtags='obs_prog,sou_area,wave_len,xcen,ycen,sht_mdur'
if not required_tags(input,reqtags,miss=miss) then begin
   box_message,['Required tags were not supplied:',miss]
   return,-1
endif

; method - define a string per image with uniq characteristics and
; invoke the UNIQ function 

tststring=strjustify(input.obs_prog) + ' '  + $
          strtrim(input.sou_area,2)  + ' '  + $
          strjustify(input.wave_len) + ' '  + $
          fstring(round(input.sht_mdur),format='(i3.3)') + ' ' + $
          trace_index2macrofov(input) 

uss=uniq(tststring,sort(tststring),/first)
nuniq=n_elements(uss)
retval=replicate(umtemplate,nuniq)
retval.uname = str_replace(strtrim(strcompress(tststring(uss)),2),' ','_')
cols=strtrim(str2cols(tststring(uss)),2)


; fill in return value structure tags
; due to RSI feature, single/multi element vectors require slightly diff handling
if nuniq eq 1 then begin
   retval.obs_prog=(reform(cols(0,*)))(0)
   retval.sou_area=(fix(reform(cols(1,*))))(0)
   retval.wave_len=(reform(cols(2,*)))(0)
   retval.sht_mdur=(reform(cols(3,*)))(0)
   retval.macrofov=(reform(cols(4,*)))(0)
endif else begin
   retval.obs_prog=reform(cols(0,*))
   retval.sou_area=fix(reform(cols(1,*)))
   retval.wave_len=reform(cols(2,*))
   retval.sht_mdur=reform(cols(3,*))
   retval.macrofov=reform(cols(4,*))
endelse

if n_params() eq 2 then begin
   retval=matchss
   nuniq=1
endif

; for every uniq set, determine how many simular records (frames...)
for i=0,nuniq-1 do begin
  ss=where(input.obs_prog eq retval(i).obs_prog and $
	   input.wave_len eq retval(i).wave_len and $
           trace_index2macrofov(input) eq retval(i).macrofov and $
           round(input.sht_mdur) eq retval(i).sht_mdur and $
           input.sou_area eq retval(i).sou_area, sscnt)
  retval(i).nmatches=sscnt
endfor  

; if a second paramter, than assume desired output is list of
; matching subscripts
if n_params() eq 2 then retval=ss else begin 
   if n_elements(exclude) eq 1 then exclude=str2arr(exclude)
   keep=lonarr(n_elements(retval))+1
   lowtst=strlowcase(tststring(uss))
   for i=0,n_elements(exclude)-1 do begin
     box_message,'excluding:'+exclude(i)
     keep=keep and $
     strpos(lowtst,strlowcase(exclude(i))) eq -1
     help,keep,where(keep)
   endfor
   keepit=where(keep,kcnt)
   if kcnt gt 0 then retval=retval(keepit) else begin
       box_message,'Nothing left after excludes!'
       retval=-1
   endelse
   if n_elements(minframes) gt 0 then begin
      ok=where(retval.nmatches ge minframes, okcnt)
      small=where(retval.nmatches lt minframes,scnt)
      if okcnt eq 0 then begin
	 box_message,'All movies fail the MINFRAMES criteria!'
	 retval=-1
       endif else begin
	 if scnt gt 0 then begin
	    retval=retval(ok)
	    box_message,'Removed '+strtrim(scnt,2) + ' movies due to MINFRAMES'
         endif
      endelse
   endif     
endelse

return , retval
end
