function trace_where, index, count, conf_file=conf_file, quiet=quiet, debug=debug, $
		      gtarr=gtarr
;+
;   Name: trace_where
;
;   Purpose: filter trace index/roadmaps - return indices of matches
;
;   Input Parameters:
;      index - TRACE input structures
; 
;   Output Parameters:
;      count - number of matches
;
;   Keyword Parameters:
;      conf_file - name of SS configuration file 
;      quite - if set, suppress messages
;        
;   History:
;       2-Feb-1998 - S.L.Freeland - adapt sxt_where to TRACE
;-
loud=1-keyword_set(quiet)
debug=keyword_set(debug)

; read SS configuration data
if not keyword_set(conf_file) then $
   conf_file=concat_dir(get_logenv('HOME'),'ss.config')
 
if not file_exist(conf_file) then begin
   message,/info,"SS configuration file: " + conf_file + " not found...
   return,-1
endif

input=rd_tfile(conf_file,/compress,nocomment=';')

sss=(where(strpos(input,'begin_ss') ne -1,s0cnt))(0)
if s0cnt eq 0 then sss=0 else sss=sss+1

sse=(where(strpos(input,'end_ss') ne -1, s1cnt))(0)
if s1cnt eq 0 then sse=n_elements(input) else sse=sse-1

gtarr=''
if sse gt sss then begin
   ss=lindgen(n_elements(index))
   ssn=sss
   repeat begin
      sscond=input(ssn)					; conditional string
      sscond=gt2exe(sscond,/addind)
      gtarr=[gtarr,sscond]
      extstr='ssnew=where(' + sscond + ',sscnt)'
      if loud then print,"FILTER>> " + extstr
      exestat=execute(extstr)
      if sscnt gt 0 then ss=ss(ssnew)
      ssn=ssn+1
      if debug then stop
    endrep until sscnt eq 0 or ssn ge sse
endif
count=0

if ssnew(0) ne -1 then count=n_elements(ssnew) else ss=-1

if debug then stop

return, ss

end
